==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/Transports/http/translations/http_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>HTTPInputFactory</name>
    <message>
        <location filename="../httpinputfactory.cpp" line="33"/>
        <source>HTTP Plugin</source>
        <translation>HTTP-liitännäinen</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="53"/>
        <source>About HTTP Transport Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="54"/>
        <source>Qmmp HTTP Transport Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="55"/>
        <source>Compiled against libcurl-%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="56"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Toteuttanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>HTTP Plugin Settings</source>
        <translation>HTTP-liitännäisen asetukset</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>Bufferin koko:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>kt</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Metadata encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="84"/>
        <source>Automatic charset detection</source>
        <translation>Automaattinen merkistön havaitseminen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Language:</source>
        <translation>Kieli:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="114"/>
        <source>Default encoding:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="137"/>
        <source>User Agent:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="151"/>
        <source>Change User Agent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/Transports/http/translations/http_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>HTTPInputFactory</name>
    <message>
        <location filename="../httpinputfactory.cpp" line="33"/>
        <source>HTTP Plugin</source>
        <translation>HTTP-liitännäinen</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="53"/>
        <source>About HTTP Transport Plugin</source>
        <translation>Tietoja HTTP Transport -liitännäinen</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="54"/>
        <source>Qmmp HTTP Transport Plugin</source>
        <translation>Qmmp HTTP Transport -liitännäinen</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="55"/>
        <source>Compiled against libcurl-%1</source>
        <translation>Käännetty vasten libcurl-%1</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="56"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Toteuttanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>HTTP Plugin Settings</source>
        <translation>HTTP-liitännäisen asetukset</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>Bufferin koko:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>kt</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Metadata encoding</source>
        <translation>Metatietojen koodaus</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="84"/>
        <source>Automatic charset detection</source>
        <translation>Automaattinen merkistön havaitseminen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Language:</source>
        <translation>Kieli:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="114"/>
        <source>Default encoding:</source>
        <translation>Oletuksena koodaus:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="137"/>
        <source>User Agent:</source>
        <translation>Käytön suoritin:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="151"/>
        <source>Change User Agent</source>
        <translation>Vaihda käytön suoritin:</translation>
    </message>
</context>
</TS>
